==> levelup-3.1.0.tgz: package/CONTRIBUTORS.md <==
# Contributors

| Name                 | GitHub                                                 | Social                                                              |
| -------------------- | ------------------------------------------------------ | ------------------------------------------------------------------- |
| **Lars-Magnus Skog** | [**@ralphtheninja**](https://github.com/ralphtheninja) | [**@ralph@social.weho.st**](https://social.weho.st/@ralph)          |
| **Rod Vagg**         | [**@rvagg**](https://github.com/rvagg)                 | [**@rvagg@twitter**](https://twitter.com/rvagg)                     |
| **Julian Gruber**    | [**@juliangruber**](https://github.com/juliangruber)   | [**@juliangruber@twitter**](https://twitter.com/juliangruber)       |
| **Dominic Tarr**     | [**@dominictarr**](https://github.com/dominictarr)     | [**@dominictarr@twitter**](https://twitter.com/dominictarr)         |
| **Vincent Weevers**  | [**@vweevers**](https://github.com/vweevers)           | [**@vweevers@twitter**](https://twitter.com/vweevers)               |
| **Matteo Collina**   | [**@mcollina**](https://github.com/mcollina)           | [**@matteocollina@twitter**](https://twitter.com/matteocollina)     |
| **James Halliday**   | [**@substack**](https://github.com/substack)           | [**@substack@twitter**](https://twitter.com/substack)               |
| **David Björklund**  | [**@kesla**](https://github.com/kesla)                 | [**@david_bjorklund@twitter**](https://twitter.com/david_bjorklund) |
| **Jake Verbaten**    | [**@Raynos**](https://github.com/Raynos)               | [**@raynos@twitter**](https://twitter.com/raynos)                   |
| **Meirion Hughes**   | [**@MeirionHughes**](https://github.com/MeirionHughes) |                                                                     |
| **Jarrett Cruger**   | [**@jcrugzz**](https://github.com/jcrugzz)             | [**@jcrugzz@twitter**](https://twitter.com/jcrugzz)                 |
| **Ben West**         | [**@bewest**](https://github.com/bewest)               |                                                                     |
| **Arnout Engelen**   | [**@raboof**](https://github.com/raboof)               |                                                                     |
| **Kyle E. Mitchell** |                                                        |                                                                     |
| **Braydon Fuller**   | [**@braydonf**](https://github.com/braydonf)           |                                                                     |
| **Huan LI**          | [**@zixia**](https://github.com/zixia)                 | [**@zixia@twitter**](https://twitter.com/zixia)                     |
| **Aditya Purwa**     | [**@adityapurwa**](https://github.com/adityapurwa)     |                                                                     |
| **Eduardo Sorribas** | [**@sorribas**](https://github.com/sorribas)           |                                                                     |
| **Nolan Lawson**     | [**@nolanlawson**](https://github.com/nolanlawson)     | [**@nolan@toot.cafe**](https://toot.cafe/@nolan)                    |
| **James Butler**     | [**@sandfox**](https://github.com/sandfox)             |                                                                     |
| **Matthew Wright**   | [**@farskipper**](https://github.com/farskipper)       |                                                                     |
| **Super-User**       |                                                        |                                                                     |
| **Pascal Temel**     | [**@PascalTemel**](https://github.com/PascalTemel)     |                                                                     |
| **Daniel Ravina**    | [**@danielravina**](https://github.com/danielravina)   |                                                                     |
| **James Brown**      |                                                        |                                                                     |
| **Alejandro Oviedo** | [**@a0viedo**](https://github.com/a0viedo)             |                                                                     |
| **Monty Anderson**   | [**@montyanderson**](https://github.com/montyanderson) |                                                                     |
| **Prayag Verma**     | [**@pra85**](https://github.com/pra85)                 |                                                                     |
| **Paolo Fragomeni**  | [**@hxoht**](https://github.com/hxoht)                 | [**@hxoht@twitter**](https://twitter.com/hxoht)                     |
| **Hans Ott**         | [**@hansott**](https://github.com/hansott)             |                                                                     |
| **Stephen Sawchuk**  |                                                        |                                                                     |
| **Richard Littauer** | [**@RichardLitt**](https://github.com/RichardLitt)     |                                                                     |
| **Brian Woodward**   | [**@doowb**](https://github.com/doowb)                 | [**@doowb@twitter**](https://twitter.com/doowb)                     |
| **Manuel Ernst**     | [**@seriousManual**](https://github.com/seriousManual) |                                                                     |
| **Calvin Metcalf**   | [**@calvinmetcalf**](https://github.com/calvinmetcalf) |                                                                     |
| **Andrew Kelley**    | [**@andrewrk**](https://github.com/andrewrk)           |                                                                     |
| **Max Ogden**        | [**@maxogden**](https://github.com/maxogden)           | [**@maxogden@twitter**](https://twitter.com/maxogden)               |
| **Patrick Pfeiffer** |                                                        |                                                                     |
| **Mark Cavage**      | [**@mcavage**](https://github.com/mcavage)             |                                                                     |
| **Pomke**            |                                                        |                                                                     |
| **Pedro Teixeira**   | [**@pgte**](https://github.com/pgte)                   | [**@pgte@twitter**](https://twitter.com/pgte)                       |
| **David Dias**       | [**@diasdavid**](https://github.com/diasdavid)         |                                                                     |

==> levelup-4.0.0.tgz: package/CONTRIBUTORS.md <==
# Contributors

| Name                 | GitHub                                                 | Social                                                              |
| :------------------- | :----------------------------------------------------- | :------------------------------------------------------------------ |
| **Lars-Magnus Skog** | [**@ralphtheninja**](https://github.com/ralphtheninja) | [**@ralph@social.weho.st**](https://social.weho.st/@ralph)          |
| **Rod Vagg**         | [**@rvagg**](https://github.com/rvagg)                 | [**@rvagg@twitter**](https://twitter.com/rvagg)                     |
| **Julian Gruber**    | [**@juliangruber**](https://github.com/juliangruber)   | [**@juliangruber@twitter**](https://twitter.com/juliangruber)       |
| **Dominic Tarr**     | [**@dominictarr**](https://github.com/dominictarr)     | [**@dominictarr@twitter**](https://twitter.com/dominictarr)         |
| **Vincent Weevers**  | [**@vweevers**](https://github.com/vweevers)           | [**@vweevers@twitter**](https://twitter.com/vweevers)               |
| **Matteo Collina**   | [**@mcollina**](https://github.com/mcollina)           | [**@matteocollina@twitter**](https://twitter.com/matteocollina)     |
| **James Halliday**   | [**@substack**](https://github.com/substack)           | [**@substack@twitter**](https://twitter.com/substack)               |
| **David Björklund**  | [**@kesla**](https://github.com/kesla)                 | [**@david_bjorklund@twitter**](https://twitter.com/david_bjorklund) |
| **Raynos**           |                                                        |                                                                     |
| **Meirion Hughes**   | [**@MeirionHughes**](https://github.com/MeirionHughes) |                                                                     |
| **Jarrett Cruger**   | [**@jcrugzz**](https://github.com/jcrugzz)             | [**@jcrugzz@twitter**](https://twitter.com/jcrugzz)                 |
| **Ben West**         | [**@bewest**](https://github.com/bewest)               |                                                                     |
| **Arnout Engelen**   | [**@raboof**](https://github.com/raboof)               |                                                                     |
| **Kyle E. Mitchell** |                                                        |                                                                     |
| **Braydon Fuller**   | [**@braydonf**](https://github.com/braydonf)           |                                                                     |
| **Huan LI**          | [**@zixia**](https://github.com/zixia)                 | [**@zixia@twitter**](https://twitter.com/zixia)                     |
| **Aditya Purwa**     | [**@adityapurwa**](https://github.com/adityapurwa)     |                                                                     |
| **Eduardo Sorribas** | [**@sorribas**](https://github.com/sorribas)           |                                                                     |
| **Nolan Lawson**     | [**@nolanlawson**](https://github.com/nolanlawson)     | [**@nolan@toot.cafe**](https://toot.cafe/@nolan)                    |
| **James Butler**     | [**@sandfox**](https://github.com/sandfox)             |                                                                     |
| **Matthew Wright**   | [**@farskipper**](https://github.com/farskipper)       |                                                                     |
| **Super-User**       |                                                        |                                                                     |
| **Pascal Temel**     | [**@PascalTemel**](https://github.com/PascalTemel)     |                                                                     |
| **Daniel Ravina**    | [**@danielravina**](https://github.com/danielravina)   |                                                                     |
| **James Brown**      |                                                        |                                                                     |
| **Alejandro Oviedo** | [**@a0viedo**](https://github.com/a0viedo)             |                                                                     |
| **Monty Anderson**   | [**@montyanderson**](https://github.com/montyanderson) |                                                                     |
| **Prayag Verma**     | [**@pra85**](https://github.com/pra85)                 |                                                                     |
| **Paolo Fragomeni**  | [**@hxoht**](https://github.com/hxoht)                 | [**@hxoht@twitter**](https://twitter.com/hxoht)                     |
| **Hans Ott**         | [**@hansott**](https://github.com/hansott)             |                                                                     |
| **Stephen Sawchuk**  |                                                        |                                                                     |
| **Richard Littauer** | [**@RichardLitt**](https://github.com/RichardLitt)     |                                                                     |
| **Brian Woodward**   | [**@doowb**](https://github.com/doowb)                 | [**@doowb@twitter**](https://twitter.com/doowb)                     |
| **Manuel Ernst**     | [**@seriousManual**](https://github.com/seriousManual) |                                                                     |
| **Calvin Metcalf**   | [**@calvinmetcalf**](https://github.com/calvinmetcalf) |                                                                     |
| **Andrew Kelley**    | [**@andrewrk**](https://github.com/andrewrk)           |                                                                     |
| **Max Ogden**        | [**@maxogden**](https://github.com/maxogden)           | [**@maxogden@twitter**](https://twitter.com/maxogden)               |
| **Patrick Pfeiffer** |                                                        |                                                                     |
| **Mark Cavage**      | [**@mcavage**](https://github.com/mcavage)             |                                                                     |
| **Pomke**            |                                                        |                                                                     |
| **Pedro Teixeira**   | [**@pgte**](https://github.com/pgte)                   | [**@pgte@twitter**](https://twitter.com/pgte)                       |
| **David Dias**       | [**@diasdavid**](https://github.com/diasdavid)         |                                                                     |
